``MatplotlibDeprecationWarning`` now subclasses ``DeprecationWarning``
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
Historically, it has not been possible to filter
``MatplotlibDeprecationWarning``\s by checking for ``DeprecationWarning``,
since we subclass ``UserWarning`` directly.

The decision to not subclass DeprecationWarning has to do with a decision from
core Python in the 2.x days to not show DeprecationWarnings to users. However,
there is now a more sophisticated filter in place (see
https://www.python.org/dev/peps/pep-0565/).

Users will now see ``MatplotlibDeprecationWarning`` only during interactive
sessions, and these can be silenced by the standard mechanism:

.. code:: python

	warnings.filterwarnings("ignore", category=DeprecationWarning)

Library authors must now enable ``DeprecationWarning``\s explicitly in order
for (non-interactive) CI/CD pipelines to report back these warnings, as is
standard for the rest of the Python ecosystem:

.. code:: python

	warnings.filterwarnings("always", DeprecationWarning)
